clear all
close all
clc

global T n w A0

% TD Signal -----------------
A0=1;

T=10e-8;  % sec
w=2*pi/T;
Ntime=1001;
dt=T/(Ntime-1);
t=(0:dt:T);
% ---------------------------

% Fourier coefficients ------
a0=(2/T)*quadl('FUNC_0',0,T,1e-16);

N=50;
for n=1:N
    a(n)=(2/T)*quadl('FUNC_COS',0,T,1e-16);
    b(n)=(2/T)*quadl('FUNC_SIN',0,T,1e-16);
end    
% ---------------------------

% Reconstruction ------------
for nt=1:Ntime
    S(nt)=a0/2;
    for n=1:N
        S(nt) = S(nt) + a(n)*cos(n*w*t(nt)) + b(n)*sin(n*w*t(nt));
    end
end    
% ---------------------------

% Visualization -------------
figure(1)
f=(0:N)*w/(2*pi);
A=[a0 a];
B=[0 b];
plot(f*1e-6,A,f*1e-6,B,'linewidth',2)
hold on
BN(1)=0;
for n=1:N
    BN(n+1) = (2*A0/(n*pi))*(1-(-1)^n);
end
plot(f*1e-6,BN,'ko','linewidth',2)
grid on
xlabel('frequency [MHz]')
ylabel('Fourier coefficients')

figure(2)
for nt=1:Ntime
    F(nt)=FUNC_0(t(nt));
end    
plot(t,F,t,S,'linewidth',2)
grid on
xlabel('time [sec]')
ylabel('Signal')

% ---------------------------